Package: pequod
Type: Package
Title: Colour Palette for Reading and Code, Inspired by Moby-Dick
Version: 0.2.0
Authors@R: person("Tiago", "Jacinto",
                  email = "tiagojacinto@med.up.pt",
                  role = c("aut", "cre"),
                  comment = c(ORCID = "0000-0002-7897-1101"))
Description: The Pequod colour palette, named after the whaler in
    Herman Melville's Moby-Dick. Provides the full Log base scale
    from warm paper (Log 50) to deep ink (Log 950), eight crew
    accent hues with light and dark variants, and 'ggplot2' scales
    for discrete and continuous mapping. Designed for long-form
    reading and code, with low saturation and a consistent earth-
    pigment register. Full design rationale and accessibility notes
    at <https://tiagojct.eu/projects/pequod/>.
License: MIT + file LICENSE
URL: https://tiagojct.eu/projects/pequod/,
        https://github.com/tiagojct/pequod
BugReports: https://github.com/tiagojct/pequod/issues
Encoding: UTF-8
Depends: R (>= 4.0.0)
Imports: ggplot2 (>= 3.3.0), grDevices, graphics, stats
Suggests: testthat (>= 3.0.0), jsonlite
Config/testthat/edition: 3
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-04-30 09:55:36 UTC; tiagojct
Author: Tiago Jacinto [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-7897-1101>)
Maintainer: Tiago Jacinto <tiagojacinto@med.up.pt>
Repository: CRAN
Date/Publication: 2026-05-01 16:40:07 UTC
Built: R 4.5.2; ; 2026-05-01 18:04:23 UTC; unix

Package: pequod
Type: Package
Title: Colour Palette for Reading and Code, Inspired by Moby-Dick
Version: 0.2.0
Authors@R: person("Tiago", "Jacinto",
                  email = "tiagojacinto@med.up.pt",
                  role = c("aut", "cre"),
                  comment = c(ORCID = "0000-0002-7897-1101"))
Description: The Pequod colour palette, named after the whaler in
    Herman Melville's Moby-Dick. Provides the full Log base scale
    from warm paper (Log 50) to deep ink (Log 950), eight crew
    accent hues with light and dark variants, and 'ggplot2' scales
    for discrete and continuous mapping. Designed for long-form
    reading and code, with low saturation and a consistent earth-
    pigment register. Full design rationale and accessibility notes
    at <https://tiagojct.eu/projects/pequod/>.
License: MIT + file LICENSE
URL: https://tiagojct.eu/projects/pequod/,
        https://github.com/tiagojct/pequod
BugReports: https://github.com/tiagojct/pequod/issues
Encoding: UTF-8
Depends: R (>= 4.0.0)
Imports: ggplot2 (>= 3.3.0), grDevices, graphics, stats
Suggests: testthat (>= 3.0.0), jsonlite
Config/testthat/edition: 3
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-04-30 09:55:36 UTC; tiagojct
Author: Tiago Jacinto [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-7897-1101>)
Maintainer: Tiago Jacinto <tiagojacinto@med.up.pt>
Repository: CRAN
Date/Publication: 2026-05-01 16:40:07 UTC
Built: R 4.6.0; ; 2026-05-01 21:21:06 UTC; unix

# Generated by roxygen2: do not edit by hand

export(palette_pequod)
export(pequod_crew)
export(pequod_crew_dark)
export(pequod_crew_light)
export(pequod_log)
export(pequod_preview)
export(scale_color_pequod_c)
export(scale_color_pequod_d)
export(scale_colour_pequod_c)
export(scale_colour_pequod_d)
export(scale_fill_pequod_c)
export(scale_fill_pequod_d)

# pequod · R package

The Pequod palette packaged for R. Provides the full Log base scale,
the eight crew accents (light and dark variants), and ggplot2 scales
for both discrete and continuous mapping.

The narrative, design rationale, and full accessibility analysis live
in the [repository README](https://github.com/tiagojct/pequod/blob/main/README.md)
and on the [project website](https://tiagojct.eu/projects/pequod/).

## Install

From GitHub (the R package lives in the `r/` subdirectory):

```r
# install.packages("remotes")
remotes::install_github("tiagojct/pequod", subdir = "r")
```

Or `devtools::install_github("tiagojct/pequod", subdir = "r")`.

## Quick start

```r
library(pequod)

# The raw palettes as named character vectors
pequod_log           # 12-step Log base scale
pequod_crew_light    # 8 accents, light variants
pequod_crew_dark     # 8 accents, dark variants

# A general-purpose palette helper
palette_pequod("log")                         # full Log scale, 12 colours
palette_pequod("crew", n = 5)                 # first five crew accents
palette_pequod("log-cool", 100, "continuous") # 100-colour interpolation

# Base-R preview
pequod_preview("log")
pequod_preview("crew")
```

## ggplot2

```r
library(ggplot2)

ggplot(iris, aes(Sepal.Length, Sepal.Width, colour = Species)) +
  geom_point(size = 3) +
  scale_color_pequod_d(palette = "crew") +
  theme_minimal()

ggplot(faithfuld, aes(waiting, eruptions, fill = density)) +
  geom_tile() +
  scale_fill_pequod_c(palette = "log-cool")
```

Both `scale_color_*` and `scale_colour_*` spellings are exported.

## Palettes

| Name        | Length | Type        | Suggested use                              |
|-------------|:-----:|-------------|--------------------------------------------|
| `log`       | 12    | sequential  | continuous gradients, heatmaps             |
| `log-warm`  | 6     | sequential  | warm side only (Log 50–400)                |
| `log-cool`  | 6     | sequential  | cool side only (Log 500–950)               |
| `crew`      | 8     | qualitative | categories, groups (light variants)        |
| `crew-dark` | 8     | qualitative | categories on a dark theme                 |
| `syntax`    | 8     | qualitative | crew in syntax-role order                  |

## Keeping tokens in sync

The canonical palette lives at `../pequod.json`. The data shipped with
this package is generated from it:

```bash
cd r
Rscript data-raw/generate_palettes.R
```

That rewrites `R/palettes-data.R` so the R values always match the
JSON tokens.

## Licence

MIT. The underlying palette tokens are also available under CC-BY-4.0
via `../pequod.json`; see `../LICENSE-CC-BY-4.0`.

#' Pequod discrete colour / fill scales for ggplot2
#'
#' Wraps [palette_pequod()] in a [ggplot2::discrete_scale()] so it can
#' be dropped into any ggplot that uses a discrete colour or fill
#' aesthetic.
#'
#' @param palette Palette name. See [palette_pequod()].
#' @param reverse Reverse the palette order.
#' @param direction `+1` (default) or `-1` to flip the palette.
#' @param ... Further arguments passed to [ggplot2::discrete_scale()].
#'
#' @return A ggplot2 scale.
#' @export
#'
#' @examples
#' library(ggplot2)
#' ggplot(iris, aes(Sepal.Length, Sepal.Width, colour = Species)) +
#'   geom_point() +
#'   scale_color_pequod_d(palette = "crew")
scale_color_pequod_d <- function(palette = "crew",
                                 reverse = FALSE,
                                 direction = 1,
                                 ...) {
  ggplot2::discrete_scale(
    aesthetics = "colour",
    palette    = .pequod_pal_d(palette, reverse, direction),
    ...
  )
}

#' @rdname scale_color_pequod_d
#' @export
scale_colour_pequod_d <- scale_color_pequod_d

#' @rdname scale_color_pequod_d
#' @export
scale_fill_pequod_d <- function(palette = "crew",
                                reverse = FALSE,
                                direction = 1,
                                ...) {
  ggplot2::discrete_scale(
    aesthetics = "fill",
    palette    = .pequod_pal_d(palette, reverse, direction),
    ...
  )
}


#' Pequod continuous colour / fill scales for ggplot2
#'
#' Interpolates across a Pequod palette with
#' [ggplot2::scale_color_gradientn()]. Best used with the `"log"` or
#' `"log-cool"` palettes, which are ordered from light to dark; the
#' `"crew"` palettes are categorical and will not interpolate cleanly.
#'
#' @param palette Palette name. See [palette_pequod()].
#' @param reverse Reverse the palette order.
#' @param ... Further arguments passed to
#'   [ggplot2::scale_color_gradientn()] / [ggplot2::scale_fill_gradientn()].
#'
#' @return A ggplot2 scale.
#' @export
#'
#' @examples
#' library(ggplot2)
#' ggplot(faithfuld, aes(waiting, eruptions, fill = density)) +
#'   geom_tile() +
#'   scale_fill_pequod_c(palette = "log-cool")
scale_color_pequod_c <- function(palette = "log", reverse = FALSE, ...) {
  cols <- palette_pequod(palette, type = "discrete")
  if (isTRUE(reverse)) cols <- rev(cols)
  ggplot2::scale_color_gradientn(colours = cols, ...)
}

#' @rdname scale_color_pequod_c
#' @export
scale_colour_pequod_c <- scale_color_pequod_c

#' @rdname scale_color_pequod_c
#' @export
scale_fill_pequod_c <- function(palette = "log", reverse = FALSE, ...) {
  cols <- palette_pequod(palette, type = "discrete")
  if (isTRUE(reverse)) cols <- rev(cols)
  ggplot2::scale_fill_gradientn(colours = cols, ...)
}


# Internal: build a palette() function that discrete_scale expects —
# it must take n and return n colours (interpolating if n exceeds the
# palette length).
.pequod_pal_d <- function(palette, reverse, direction) {
  cols <- palette_pequod(palette, type = "discrete")
  if (isTRUE(reverse) || direction == -1) cols <- rev(cols)
  function(n) {
    if (n > length(cols)) {
      grDevices::colorRampPalette(cols)(n)
    } else {
      cols[seq_len(n)]
    }
  }
}

test_that("log scale has twelve steps, named Log 50 to Log 950", {
  expect_length(pequod_log, 12)
  expect_identical(names(pequod_log)[1], "Log 50")
  expect_identical(names(pequod_log)[12], "Log 950")
})

test_that("crew palettes have eight named entries each", {
  expect_length(pequod_crew_light, 8)
  expect_length(pequod_crew_dark, 8)
  expect_identical(names(pequod_crew_light), names(pequod_crew_dark))
  expect_setequal(
    names(pequod_crew_light),
    c("Ahab", "Starbuck", "Queequeg", "Pip",
      "Ishmael", "Stubb", "Tashtego", "Daggoo")
  )
})

test_that("every palette entry is a valid six-digit hex code", {
  all_hex <- c(pequod_log, pequod_crew_light, pequod_crew_dark)
  expect_true(all(grepl("^#[0-9A-Fa-f]{6}$", all_hex)))
})

test_that("pequod_crew bundles light, dark, and roles", {
  expect_named(pequod_crew, c("light", "dark", "roles"))
  expect_length(pequod_crew$roles, 8)
})

test_that("palette_pequod returns an unnamed character vector", {
  x <- palette_pequod("log")
  expect_type(x, "character")
  expect_length(x, 12)
  expect_null(names(x))
})

test_that("palette_pequod supports continuous interpolation", {
  x <- palette_pequod("log", n = 100, type = "continuous")
  expect_length(x, 100)
  expect_true(all(grepl("^#[0-9A-Fa-f]{6}$", x)))
})

test_that("palette_pequod reverse flag flips the palette", {
  fwd <- palette_pequod("log")
  rev <- palette_pequod("log", reverse = TRUE)
  expect_identical(fwd, rev(rev))
})

test_that("palette_pequod errors on unknown palette name", {
  expect_error(palette_pequod("nonexistent"), "Unknown palette")
})

test_that("palette_pequod errors when requesting too many discrete colours", {
  expect_error(palette_pequod("crew", n = 100), "has only")
})

test_that("ggplot2 scale builders return Scale objects", {
  skip_if_not_installed("ggplot2")
  expect_s3_class(scale_color_pequod_d(), "Scale")
  expect_s3_class(scale_fill_pequod_d(), "Scale")
  expect_s3_class(scale_color_pequod_c(), "Scale")
  expect_s3_class(scale_fill_pequod_c(), "Scale")
})

#' pequod: A Pigment-Inspired Colour Palette for R
#'
#' The Pequod colour palette for R — the full twelve-step Log base
#' scale (`pequod_log`), eight crew accent hues in light and dark
#' variants (`pequod_crew_light`, `pequod_crew_dark`), a general
#' palette function (`palette_pequod()`), and ggplot2 scales
#' (`scale_color_pequod_d()`, `scale_fill_pequod_d()`,
#' `scale_color_pequod_c()`, `scale_fill_pequod_c()`).
#'
#' See <https://tiagojct.eu/projects/pequod/> for the full palette
#' narrative, WCAG contrast ratios, and colour-vision-deficiency
#' analysis. The upstream source of truth is
#' <https://github.com/tiagojct/pequod>.
#'
#' @keywords internal
"_PACKAGE"

#' Preview a Pequod palette
#'
#' Draws a strip of coloured rectangles with labels using base R
#' graphics. Useful for seeing a palette before committing to it in
#' an analysis.
#'
#' @param palette Palette name. See [palette_pequod()].
#' @param labels If `TRUE` (default) writes each colour's label above
#'   the rectangle.
#'
#' @return The palette, invisibly.
#' @export
#'
#' @examples
#' pequod_preview("log")
#' pequod_preview("crew")
pequod_preview <- function(palette = "log", labels = TRUE) {
  cols <- palette_pequod(palette, type = "discrete")
  # Names are dropped inside palette_pequod() — reach back to the map
  # for labels so the preview stays meaningful.
  map <- .pequod_palette_map()
  nm <- names(map[[palette]])
  if (is.null(nm)) nm <- seq_along(cols)

  n <- length(cols)
  op <- graphics::par(mar = c(2, 1, 3, 1))
  on.exit(graphics::par(op), add = TRUE)

  graphics::plot.new()
  graphics::plot.window(xlim = c(0, n), ylim = c(0, 1), asp = NA)

  for (i in seq_len(n)) {
    graphics::rect(i - 1, 0, i, 1, col = cols[i], border = NA)
    if (labels) {
      graphics::text(i - 0.5, 1.05, labels = nm[i],
                     cex = 0.75, xpd = NA, srt = 0)
    }
  }

  graphics::title(main = paste0("Pequod: ", palette), cex.main = 0.95)

  invisible(stats::setNames(cols, nm))
}

# Generated from ../pequod.json (v0.1.0-alpha).
# Re-generate with: Rscript data-raw/generate_palettes.R

#' Pequod Log base scale
#'
#' The twelve-step base scale, from warm paper (`Log 50`) to the
#' night-before-the-storm ink of `Log 950`. Warm on the paper side,
#' cool on the ink side; the hinge sits between Log 500 (warm
#' taupe) and Log 700 (cool sage).
#'
#' @format A named character vector of length 12 (hex codes).
#' @export
pequod_log <- c(
  "Log 50"  = "#FBFAF5",
  "Log 100" = "#F8F4EB",
  "Log 150" = "#ECE5D3",
  "Log 200" = "#DFD3B8",
  "Log 300" = "#C4A57B",
  "Log 400" = "#A8865E",
  "Log 500" = "#8B7B6B",
  "Log 600" = "#6E5F52",
  "Log 700" = "#527275",
  "Log 800" = "#2C3E50",
  "Log 900" = "#1C2936",
  "Log 950" = "#13181F"
)

#' Pequod crew accents — light variants
#'
#' Eight accent hues, each named after a character in *Moby-Dick*,
#' tuned to sit against a Log 100 paper surface.
#'
#' @format A named character vector of length 8.
#' @export
pequod_crew_light <- c(
  "Ahab"     = "#B5534A",
  "Starbuck" = "#527C98",
  "Queequeg" = "#4A4E8C",
  "Pip"      = "#A8812B",
  "Ishmael"  = "#6E6E6B",
  "Stubb"    = "#B5683A",
  "Tashtego" = "#507352",
  "Daggoo"   = "#7A5440"
)

#' Pequod crew accents — dark variants
#'
#' Eight accent hues tuned to sit against the Log 950 ink surface.
#'
#' @format A named character vector of length 8.
#' @export
pequod_crew_dark <- c(
  "Ahab"     = "#E07A72",
  "Starbuck" = "#7FA8C3",
  "Queequeg" = "#8A8ECE",
  "Pip"      = "#D9B461",
  "Ishmael"  = "#A5A5A0",
  "Stubb"    = "#E29B6E",
  "Tashtego" = "#8AB08C",
  "Daggoo"   = "#AF8870"
)

#' Pequod crew metadata
#'
#' A list bundling the light and dark crew accents together with
#' their suggested syntax roles.
#'
#' @format A list with three elements: `light`, `dark`, `roles`.
#' @export
pequod_crew <- list(
  light = pequod_crew_light,
  dark  = pequod_crew_dark,
  roles = c(
    "Ahab"     = "red",
    "Starbuck" = "blue",
    "Queequeg" = "indigo",
    "Pip"      = "yellow",
    "Ishmael"  = "grey",
    "Stubb"    = "orange",
    "Tashtego" = "green",
    "Daggoo"   = "brown"
  )
)

#' Pequod palette
#'
#' Returns a character vector of hex colours from a named Pequod
#' palette. Supports both discrete selection (first `n` colours) and
#' continuous interpolation between the palette's stops.
#'
#' Available palettes:
#' \describe{
#'   \item{`"log"`}{The full 12-step Log base scale.}
#'   \item{`"log-warm"`}{Log 50–400 (six warm steps).}
#'   \item{`"log-cool"`}{Log 500–950 (six cool steps).}
#'   \item{`"crew"`}{The eight crew accents, light variants.}
#'   \item{`"crew-dark"`}{The eight crew accents, dark variants.}
#'   \item{`"syntax"`}{Crew accents in syntax-role order — keyword,
#'     string, number, comment, function, type, constant, variable.}
#' }
#'
#' @param name Palette name; see Details.
#' @param n Number of colours to return. Defaults to the full palette
#'   length. For `type = "continuous"`, any positive integer.
#' @param type `"discrete"` takes the first `n` colours (errors if `n`
#'   exceeds the palette length). `"continuous"` interpolates `n`
#'   colours across the full palette with [grDevices::colorRampPalette()].
#' @param reverse If `TRUE`, reverse the returned palette.
#' @param direction `+1` (default) or `-1` to flip the palette.
#'
#' @return An unnamed character vector of hex codes of length `n`.
#' @export
#'
#' @examples
#' palette_pequod("log")
#' palette_pequod("crew", n = 5)
#' palette_pequod("log-cool", n = 100, type = "continuous")
palette_pequod <- function(name = "log",
                           n = NULL,
                           type = c("discrete", "continuous"),
                           reverse = FALSE,
                           direction = 1) {
  type <- match.arg(type)
  palettes <- .pequod_palette_map()

  if (!name %in% names(palettes)) {
    stop(
      "Unknown palette '", name, "'. Available palettes: ",
      paste(names(palettes), collapse = ", "),
      call. = FALSE
    )
  }

  cols <- palettes[[name]]
  if (is.null(n)) n <- length(cols)
  if (n < 1L) stop("`n` must be a positive integer.", call. = FALSE)

  if (type == "discrete") {
    if (n > length(cols)) {
      stop(
        "Requested ", n, " colours from palette '", name,
        "' which has only ", length(cols), ". ",
        "Use type = 'continuous' to interpolate.",
        call. = FALSE
      )
    }
    out <- cols[seq_len(n)]
  } else {
    out <- grDevices::colorRampPalette(cols)(n)
  }

  if (isTRUE(reverse) || direction == -1) out <- rev(out)
  unname(out)
}

# Internal: master palette lookup table.
.pequod_palette_map <- function() {
  list(
    "log"       = pequod_log,
    "log-warm"  = pequod_log[1:6],
    "log-cool"  = pequod_log[7:12],
    "crew"      = pequod_crew_light,
    "crew-dark" = pequod_crew_dark,
    "syntax"    = pequod_crew_light[c(
      "Ahab", "Tashtego", "Pip", "Ishmael",
      "Starbuck", "Queequeg", "Stubb", "Daggoo"
    )]
  )
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/palettes-data.R
\docType{data}
\name{pequod_crew_dark}
\alias{pequod_crew_dark}
\title{Pequod crew accents — dark variants}
\format{
A named character vector of length 8.
}
\usage{
pequod_crew_dark
}
\description{
Eight accent hues tuned to sit against the Log 950 ink surface.
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scales.R
\name{scale_color_pequod_c}
\alias{scale_color_pequod_c}
\alias{scale_colour_pequod_c}
\alias{scale_fill_pequod_c}
\title{Pequod continuous colour / fill scales for ggplot2}
\usage{
scale_color_pequod_c(palette = "log", reverse = FALSE, ...)

scale_colour_pequod_c(palette = "log", reverse = FALSE, ...)

scale_fill_pequod_c(palette = "log", reverse = FALSE, ...)
}
\arguments{
\item{palette}{Palette name. See [palette_pequod()].}

\item{reverse}{Reverse the palette order.}

\item{...}{Further arguments passed to
[ggplot2::scale_color_gradientn()] / [ggplot2::scale_fill_gradientn()].}
}
\value{
A ggplot2 scale.
}
\description{
Interpolates across a Pequod palette with
[ggplot2::scale_color_gradientn()]. Best used with the `"log"` or
`"log-cool"` palettes, which are ordered from light to dark; the
`"crew"` palettes are categorical and will not interpolate cleanly.
}
\examples{
library(ggplot2)
ggplot(faithfuld, aes(waiting, eruptions, fill = density)) +
  geom_tile() +
  scale_fill_pequod_c(palette = "log-cool")
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/palettes-data.R
\docType{data}
\name{pequod_crew_light}
\alias{pequod_crew_light}
\title{Pequod crew accents — light variants}
\format{
A named character vector of length 8.
}
\usage{
pequod_crew_light
}
\description{
Eight accent hues, each named after a character in *Moby-Dick*,
tuned to sit against a Log 100 paper surface.
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/palettes-data.R
\docType{data}
\name{pequod_crew}
\alias{pequod_crew}
\title{Pequod crew metadata}
\format{
A list with three elements: `light`, `dark`, `roles`.
}
\usage{
pequod_crew
}
\description{
A list bundling the light and dark crew accents together with
their suggested syntax roles.
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scales.R
\name{scale_color_pequod_d}
\alias{scale_color_pequod_d}
\alias{scale_colour_pequod_d}
\alias{scale_fill_pequod_d}
\title{Pequod discrete colour / fill scales for ggplot2}
\usage{
scale_color_pequod_d(palette = "crew", reverse = FALSE, direction = 1, ...)

scale_colour_pequod_d(palette = "crew", reverse = FALSE, direction = 1, ...)

scale_fill_pequod_d(palette = "crew", reverse = FALSE, direction = 1, ...)
}
\arguments{
\item{palette}{Palette name. See [palette_pequod()].}

\item{reverse}{Reverse the palette order.}

\item{direction}{`+1` (default) or `-1` to flip the palette.}

\item{...}{Further arguments passed to [ggplot2::discrete_scale()].}
}
\value{
A ggplot2 scale.
}
\description{
Wraps [palette_pequod()] in a [ggplot2::discrete_scale()] so it can
be dropped into any ggplot that uses a discrete colour or fill
aesthetic.
}
\examples{
library(ggplot2)
ggplot(iris, aes(Sepal.Length, Sepal.Width, colour = Species)) +
  geom_point() +
  scale_color_pequod_d(palette = "crew")
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/preview.R
\name{pequod_preview}
\alias{pequod_preview}
\title{Preview a Pequod palette}
\usage{
pequod_preview(palette = "log", labels = TRUE)
}
\arguments{
\item{palette}{Palette name. See [palette_pequod()].}

\item{labels}{If `TRUE` (default) writes each colour's label above
the rectangle.}
}
\value{
The palette, invisibly.
}
\description{
Draws a strip of coloured rectangles with labels using base R
graphics. Useful for seeing a palette before committing to it in
an analysis.
}
\examples{
pequod_preview("log")
pequod_preview("crew")
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/palettes.R
\name{palette_pequod}
\alias{palette_pequod}
\title{Pequod palette}
\usage{
palette_pequod(
  name = "log",
  n = NULL,
  type = c("discrete", "continuous"),
  reverse = FALSE,
  direction = 1
)
}
\arguments{
\item{name}{Palette name; see Details.}

\item{n}{Number of colours to return. Defaults to the full palette
length. For `type = "continuous"`, any positive integer.}

\item{type}{`"discrete"` takes the first `n` colours (errors if `n`
exceeds the palette length). `"continuous"` interpolates `n`
colours across the full palette with [grDevices::colorRampPalette()].}

\item{reverse}{If `TRUE`, reverse the returned palette.}

\item{direction}{`+1` (default) or `-1` to flip the palette.}
}
\value{
An unnamed character vector of hex codes of length `n`.
}
\description{
Returns a character vector of hex colours from a named Pequod
palette. Supports both discrete selection (first `n` colours) and
continuous interpolation between the palette's stops.
}
\details{
Available palettes:
\describe{
  \item{`"log"`}{The full 12-step Log base scale.}
  \item{`"log-warm"`}{Log 50–400 (six warm steps).}
  \item{`"log-cool"`}{Log 500–950 (six cool steps).}
  \item{`"crew"`}{The eight crew accents, light variants.}
  \item{`"crew-dark"`}{The eight crew accents, dark variants.}
  \item{`"syntax"`}{Crew accents in syntax-role order — keyword,
    string, number, comment, function, type, constant, variable.}
}
}
\examples{
palette_pequod("log")
palette_pequod("crew", n = 5)
palette_pequod("log-cool", n = 100, type = "continuous")
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pequod-package.R
\docType{package}
\name{pequod-package}
\alias{pequod}
\alias{pequod-package}
\title{pequod: A Pigment-Inspired Colour Palette for R}
\description{
The Pequod colour palette for R — the full twelve-step Log base
scale (`pequod_log`), eight crew accent hues in light and dark
variants (`pequod_crew_light`, `pequod_crew_dark`), a general
palette function (`palette_pequod()`), and ggplot2 scales
(`scale_color_pequod_d()`, `scale_fill_pequod_d()`,
`scale_color_pequod_c()`, `scale_fill_pequod_c()`).
}
\details{
See <https://tiagojct.eu/projects/pequod/> for the full palette
narrative, WCAG contrast ratios, and colour-vision-deficiency
analysis. The upstream source of truth is
<https://github.com/tiagojct/pequod>.
}
\seealso{
Useful links:
\itemize{
  \item \url{https://tiagojct.eu/projects/pequod/}
  \item \url{https://github.com/tiagojct/pequod}
  \item Report bugs at \url{https://github.com/tiagojct/pequod/issues}
}

}
\author{
\strong{Maintainer}: Tiago Jacinto \email{tiagojacinto@med.up.pt} (\href{https://orcid.org/0000-0002-7897-1101}{ORCID})

}
\keyword{internal}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/palettes-data.R
\docType{data}
\name{pequod_log}
\alias{pequod_log}
\title{Pequod Log base scale}
\format{
A named character vector of length 12 (hex codes).
}
\usage{
pequod_log
}
\description{
The twelve-step base scale, from warm paper (`Log 50`) to the
night-before-the-storm ink of `Log 950`. Warm on the paper side,
cool on the ink side; the hinge sits between Log 500 (warm
taupe) and Log 700 (cool sage).
}
\keyword{datasets}
